Exception: HotCell::Fixtures::LibraryError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/hot_cell/test_operations.rb

Overview

A library exception an operation declares as meaning "the input could not be decoded", the way the Active Storage operations will declare Vips::Error.