Exception: HotCell::OperationError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/hot_cell/server/errors.rb

Overview

What an operation raises to choose its own verdict. An operation may also declare the library exceptions that mean the same thing, with unreadable Vips::Error.

Direct Known Subclasses

MemoryExhausted, UnreadableInput